@@ -1,7 +1,7 @@
 .onAttach <- function(libname, pkgname) {
-	
-	c.config <- lsgl.c.config()
-	
+
+	c.config <- sgl.c.config()
+
 	if(c.config$debugging) packageStartupMessage("lsgl: Compiled with debugging on -- this may slow down runtime")
-	
-}
\ No newline at end of file
+
+}
