@@ -1,4 +1,4 @@
-//R interface
+/R interface
 
 extern "C" {
 
@@ -14,12 +14,6 @@ SEXP pkg_c_config() {
 	debug_on = true;
 #endif
 
-	//omp support
-	bool omp_supp = false;
-#ifdef SGL_OPENMP_SUPP
-	omp_supp = true;
-#endif
-
 	//profiling
 	bool timing = false;
 #ifdef DO_TIMING
@@ -53,7 +47,6 @@ SEXP pkg_c_config() {
 	rList res;
 	res.attach(rObject(debug_on), "debugging");
 	res.attach(rObject(timing), "timing");
-	res.attach(rObject(omp_supp), "omp.supported");
 	res.attach(rObject(runtime_checks), "runtime.checks");
 	res.attach(rObject(dim_checks), "dim.checks");
 	res.attach(rObject(conv_check), "convergence.checks");
